jschon-translation
==================

|tests| |codecov| |pypi| |python| |license|

An implementation of a JSON Schema
`translation vocabulary <https://github.com/marksparkza/json-translation-vocabulary>`_,
that enables you to translate JSON documents from your validating schema to one or more
differently structured schemas.

Based on `jschon <https://github.com/marksparkza/jschon>`_.

.. |tests| image:: https://github.com/marksparkza/jschon-translation/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/marksparkza/jschon-translation/actions/workflows/tests.yml
    :alt: Test Status

.. |codecov| image:: https://codecov.io/gh/marksparkza/jschon-translation/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/marksparkza/jschon-translation
    :alt: Code Coverage

.. |pypi| image:: https://img.shields.io/pypi/v/jschon-translation
    :target: https://pypi.org/project/jschon-translation
    :alt: PyPI Package Version

.. |python| image:: https://img.shields.io/pypi/pyversions/jschon-translation
    :target: https://pypi.org/project/jschon-translation
    :alt: Python Versions

.. |license| image:: https://img.shields.io/github/license/marksparkza/jschon-translation
    :target: https://github.com/marksparkza/jschon-translation/blob/main/LICENSE
    :alt: License
